from ks_response.response import KSResponse
from ks_response.response import StandardCode
import afs_api_worker.exceptions as api_exception


class ApiWorker(object):
    """

    Класс для работы с AFS Api
    Attributes:
        server: Адресс сервера
        api_version: Версия api
    """
    def __init__(self, server: str, api_version: int):
        """Инициализация ApiWorker"""
        self.server = server
        self.api_version = api_version
        self.api_url = self.server + 'api/v{0}/'.format(self.api_version)
        self._ks_response = KSResponse(server, api_version)

    def get_testrun_data(self, testrun_id: int):
        """Получение данных TestRun"""
        ks_response = self._ks_response.get_method('testrun/{0}/'.format(testrun_id))

        if ks_response.response_code != StandardCode.OK:
            raise api_exception.NotOkResponseException(ks_response.response_message)
        return ks_response.response_data

    def get_testcase(self, name: str):
        """Получение данных TestCase"""
        ks_response = self._ks_response.get_method('testcase/', params={"name": name})
        if ks_response.response_code != StandardCode.OK:
            raise api_exception.NotOkResponseException(ks_response.response_message)
        return ks_response.response_data

    def get_testsuite(self, file: str):
        """Получение данных TestCase"""
        ks_response = self._ks_response.get_method('testsuite/', params={"file": file})
        if ks_response.response_code != StandardCode.OK:
            raise api_exception.NotOkResponseException(ks_response.response_message)
        return ks_response.response_data

    def get_testsuiterun(self, testsuiterun_id):
        """Получение данных TestCase"""
        ks_response = self._ks_response.get_method('testsuiterun/{0}' .format(testsuiterun_id))
        if ks_response.response_code != StandardCode.OK:
            raise api_exception.NotOkResponseException(ks_response.response_message)
        return ks_response.response_data

    def get_project(self, project_id: int):
        """Получение данных TestProject"""
        ks_response = self._ks_response.get_method('project/' + str(project_id))
        if ks_response.response_code != StandardCode.OK:
            raise api_exception.NotOkResponseException(ks_response.response_message)
        return ks_response.response_data
